==> haskell-io-streams-haproxy-1.0.0.2-32-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.0.2
id: io-streams-haproxy-1.0.0.2-GfZt3Iy6BiE70tMARBUdww
key: io-streams-haproxy-1.0.0.2-GfZt3Iy6BiE70tMARBUdww
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: 6de43f5c1f3f53ddb0dfe06f2aba1f2c
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.6.1/site-local/io-streams-haproxy-1.0.0.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/io-streams-haproxy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/io-streams-haproxy-1.0.0.2
hs-libraries: HSio-streams-haproxy-1.0.0.2-GfZt3Iy6BiE70tMARBUdww
depends:
    attoparsec-0.13.2.2-HPD0YgNwhBr5J2x8QxeYlI base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.0.1-HEyTu7o7nLP6StPuBXK7L1
    network-2.7.0.2-Fxn7IKbIXjq1GwNvEyamvn transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-io-streams-haproxy-1.0.0.2-34-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-io-streams-haproxy.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: io-streams-haproxy
version: 1.0.0.2
id: io-streams-haproxy-1.0.0.2-Famkri0JrzCFDyMCR3FEoF
key: io-streams-haproxy-1.0.0.2-Famkri0JrzCFDyMCR3FEoF
license: BSD-3-Clause
copyright: (c) 2014 Google, Inc. and CONTRIBUTORS
maintainer: greg@gregorycollins.net
author: Gregory Collins
homepage: http://snapframework.com/
synopsis: HAProxy protocol 1.5 support for io-streams
description:
    HAProxy protocol version 1.5 support (see
    <http://haproxy.1wt.eu/download/1.5/doc/proxy-protocol.txt>) for applications
    using io-streams. The proxy protocol allows information about a networked
    peer (like remote address and port) to be propagated through a forwarding
    proxy that is configured to speak this protocol.
category: Network, IO-Streams
abi: 4a5227870602d3939b6ca0defb9fd973
exposed: True
exposed-modules:
    System.IO.Streams.Network.HAProxy
hidden-modules: System.IO.Streams.Network.Internal.Address
import-dirs: /usr/lib/ghc-8.6.2/site-local/io-streams-haproxy-1.0.0.2
library-dirs: /usr/lib/ghc-8.6.2/site-local/io-streams-haproxy-1.0.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.2/io-streams-haproxy-1.0.0.2
hs-libraries: HSio-streams-haproxy-1.0.0.2-Famkri0JrzCFDyMCR3FEoF
depends:
    attoparsec-0.13.2.2-CmkmuzHxC7WKLrfPgrn9Wq base-4.12.0.0
    bytestring-0.10.8.2 io-streams-1.5.0.1-7oJHkzP57f88H6M84jYHTU
    network-2.7.0.2-2fEEs0vTvHq3lWAStilHpJ transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-io-streams-haproxy/html/io-streams-haproxy.haddock
haddock-html: /usr/share/doc/haskell-io-streams-haproxy/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
